HydraPlatform
=============

[![Build Status](https://travis-ci.org/hydraplatform/hydra-base.svg?branch=master)](https://travis-ci.org/hydraplatform/hydra-base)


A library for managing networks. Full documentation can be found [here](http://umwrg.github.io/HydraPlatform/).


Installation
------------

pip install hydra-base


Usage
-----

Hydra base can be used in conjunction with a [hydra server](https://github.com/hydraplatform/hydra-server).

Hydra server relies on web clients sending it requests. Usefully, there is a hydra client
libary [here](https://github.com/hydraplatform/hydra-client-python) with some example on how to use the system.

